@@ -2,11 +2,15 @@ import pandas as pd
 import xarray as xr
 import numpy as np
 from ark.utils import spatial_analysis_utils
+from ark.utils import misc_utils
+
+import ark.settings as settings
 
 
 def calculate_channel_spatial_enrichment(dist_matrices_dict, marker_thresholds, all_data,
-                                         excluded_colnames=None, included_fovs=None,
-                                         dist_lim=100, bootstrap_num=1000, fov_col="SampleID"):
+                                         excluded_channels=None, included_fovs=None,
+                                         dist_lim=100, bootstrap_num=1000,
+                                         fov_col=settings.FOV_ID):
     """Spatial enrichment analysis to find significant interactions between cells expressing
     different markers. Uses bootstrapping to permute cell labels randomly.
 
@@ -18,12 +22,8 @@ def calculate_channel_spatial_enrichment(dist_matrices_dict, marker_thresholds,
             threshold values for positive marker expression
         all_data (pandas.DataFrame):
             data including fovs, cell labels, and cell expression matrix for all markers
-        excluded_colnames (list):
-            all column names that are not markers. If argument is none, default is
-            ["cell_size", "Background", "HH3",
-            "summed_channel", "label", "area",
-            "eccentricity", "major_axis_length",
-            "minor_axis_length", "perimeter", "fov"]
+        excluded_channels (list):
+            channels to be excluded from the analysis.  Default is None.
         included_fovs (list):
             patient labels to include in analysis. If argument is none, default is all labels used.
         dist_lim (int):
@@ -31,7 +31,7 @@ def calculate_channel_spatial_enrichment(dist_matrices_dict, marker_thresholds,
         bootstrap_num (int):
             number of permutations for bootstrap. Default is 1000.
         fov_col (str):
-            column with the cell fovs. Default is 'SampleID'
+            column with the cell fovs.
 
     Returns:
         tuple (list, xarray.DataArray):
@@ -52,27 +52,24 @@ def calculate_channel_spatial_enrichment(dist_matrices_dict, marker_thresholds,
 
     values = []
 
-    if excluded_colnames is None:
-        excluded_colnames = ["cell_size", "Background", "HH3",
-                             "summed_channel", "label", "area",
-                             "eccentricity", "major_axis_length", "minor_axis_length",
-                             "perimeter", "fov"]
+    # check if included fovs found in fov_col
+    misc_utils.verify_in_list(fov_names=included_fovs,
+                              unique_fovs=all_data[fov_col].unique())
 
-    # Error Checking
-    if not np.isin(excluded_colnames, all_data.columns).all():
-        raise ValueError("Column names were not found in Expression Matrix")
-
-    if not np.isin(included_fovs, all_data[fov_col]).all():
-        raise ValueError("Fovs were not found in Expression Matrix")
+    # check if all excluded column names found in all_data
+    misc_utils.verify_in_list(columns_to_exclude=excluded_channels,
+                              column_names=all_data.columns)
 
     # Subsets the expression matrix to only have channel columns
-    all_channel_data = all_data.drop(excluded_colnames, axis=1)
+    channel_start = np.where(all_data.columns == settings.PRE_CHANNEL_COL)[0][0] + 1
+    channel_end = np.where(all_data.columns == settings.POST_CHANNEL_COL)[0][0]
 
-    # this will get refactored once the verification refactor PR gets merged in
-    if not np.all(set(marker_thresholds.iloc[:, 0]) == set(all_channel_data.columns)):
-        raise ValueError(
-            "The same markers must be found in marker thresholds and expression matrix columns"
-        )
+    all_channel_data = all_data.iloc[:, channel_start:channel_end]
+    all_channel_data = all_channel_data.drop(excluded_channels, axis=1)
+
+    # check that the markers are the same in marker_thresholdsa and all_channel_data
+    misc_utils.verify_same_elements(markers_to_threshold=marker_thresholds.iloc[:, 0].values,
+                                    all_markers=all_channel_data.columns.values)
 
     # reorder all_channel_data's marker columns the same as they appear in marker_thresholds
     all_channel_data = all_channel_data[marker_thresholds.iloc[:, 0].values]
@@ -95,6 +92,7 @@ def calculate_channel_spatial_enrichment(dist_matrices_dict, marker_thresholds,
         # Subsetting expression matrix to only include patients with correct fov label
         current_fov_idx = all_data[fov_col] == fov
         current_fov_data = all_data[current_fov_idx]
+
         # Patients with correct label, and only columns of channel markers
         current_fov_channel_data = all_channel_data[current_fov_idx]
 
@@ -119,9 +117,10 @@ def calculate_channel_spatial_enrichment(dist_matrices_dict, marker_thresholds,
 
 
 def calculate_cluster_spatial_enrichment(all_data, dist_matrices_dict, included_fovs=None,
-                                         bootstrap_num=1000, dist_lim=100, fov_col="SampleID",
-                                         cluster_name_col="cell_type", cluster_id_col="FlowSOM_ID",
-                                         cell_label_col="cellLabelInImage", context_labels=None):
+                                         bootstrap_num=1000, dist_lim=100, fov_col=settings.FOV_ID,
+                                         cluster_name_col=settings.CELL_TYPE,
+                                         cluster_id_col=settings.CLUSTER_ID,
+                                         cell_label_col=settings.CELL_LABEL, context_labels=None):
     """Spatial enrichment analysis based on cell phenotypes to find significant interactions
     between different cell types, looking for both positive and negative enrichment. Uses
     bootstrapping to permute cell labels randomly.
@@ -139,13 +138,13 @@ def calculate_cluster_spatial_enrichment(all_data, dist_matrices_dict, included_
         dist_lim (int):
             cell proximity threshold. Default is 100
         fov_col (str):
-            column with the cell fovs. Default is 'SampleID'
+            column with the cell fovs.
         cluster_name_col (str):
-            column with the cell types. Default is 'cell_type'
+            column with the cell types.
         cluster_id_col (str):
-            column with the cell phenotype IDs. Default is 'FlowSOM_ID'
+            column with the cell phenotype IDs.
         cell_label_col (str):
-            column with the cell labels. Default is 'cellLabelInImage'
+            column with the cell labels.
         context_labels (dict):
             A dict that contains which specific types of cells we want to consider.
             If argument is None, we will not run context-dependent spatial analysis
@@ -169,9 +168,9 @@ def calculate_cluster_spatial_enrichment(all_data, dist_matrices_dict, included_
 
     values = []
 
-    # Error Checking
-    if not np.isin(included_fovs, all_data[fov_col]).all():
-        raise ValueError("Fovs were not found in Expression Matrix")
+    # check if included fovs found in fov_col
+    misc_utils.verify_in_list(fov_names=included_fovs,
+                              unique_fovs=all_data[fov_col].unique())
 
     # Extract the names of the cell phenotypes
     cluster_names = all_data[cluster_name_col].drop_duplicates()
@@ -219,8 +218,9 @@ def calculate_cluster_spatial_enrichment(all_data, dist_matrices_dict, included_
 
 
 def create_neighborhood_matrix(all_data, dist_matrices_dict, included_fovs=None, distlim=50,
-                               fov_col="SampleID", cluster_id_col="FlowSOM_ID",
-                               cell_label_col="cellLabelInImage", cluster_name_col="cell_type"):
+                               fov_col=settings.FOV_ID, cluster_id_col=settings.CLUSTER_ID,
+                               cell_label_col=settings.CELL_LABEL,
+                               cluster_name_col=settings.CELL_TYPE):
     """Calculates the number of neighbor phenotypes for each cell.
 
     Args:
@@ -234,13 +234,13 @@ def create_neighborhood_matrix(all_data, dist_matrices_dict, included_fovs=None,
         distlim (int):
             cell proximity threshold. Default is 50.
         fov_col (str):
-            column with the cell fovs. Default is 'SampleID'
+            column with the cell fovs.
         cluster_id_col (str):
-            column with the cell phenotype IDs. Default is 'FlowSOM_ID'
+            column with the cell phenotype IDs.
         cell_label_col (str):
-            column with the cell labels. Default is 'cellLabelInImage'
+            column with the cell labels.
         cluster_name_col (str):
-            column with the cell types. Default is 'cell_type'
+            column with the cell types.
 
     Returns:
         pandas.DataFrame:
@@ -252,9 +252,9 @@ def create_neighborhood_matrix(all_data, dist_matrices_dict, included_fovs=None,
     if included_fovs is None:
         included_fovs = all_data[fov_col].unique()
 
-    # Error Checking
-    if not np.isin(included_fovs, all_data[fov_col]).all():
-        raise ValueError("Fovs were not found in Expression Matrix")
+    # check if included fovs found in fov_col
+    misc_utils.verify_in_list(fov_names=included_fovs,
+                              unique_fovs=all_data[fov_col].unique())
 
     # Get the phenotypes
     cluster_names = all_data[cluster_name_col].drop_duplicates()
@@ -299,12 +299,16 @@ def create_neighborhood_matrix(all_data, dist_matrices_dict, included_fovs=None,
         cell_neighbor_counts.loc[current_fov_neighborhood_data.index, fov_cluster_names] = counts
         cell_neighbor_freqs.loc[current_fov_neighborhood_data.index, fov_cluster_names] = freqs
 
+    # drop label column, as this interferes with the neighborhood clustering step
+    cell_neighbor_counts = cell_neighbor_counts.drop(columns=cell_label_col)
+    cell_neighbor_freqs = cell_neighbor_freqs.drop(columns=cell_label_col)
+
     return cell_neighbor_counts, cell_neighbor_freqs
 
 
-def generate_cluster_matrix_results(all_data, neighbor_mat, cluster_num, excluded_colnames=None,
-                                    included_fovs=None, cluster_label_col='cluster_labels',
-                                    fov_col='SampleID', cell_type_col='cell_type'):
+def generate_cluster_matrix_results(all_data, neighbor_mat, cluster_num, excluded_channels=None,
+                                    included_fovs=None, cluster_label_col=settings.KMEANS_CLUSTER,
+                                    fov_col=settings.FOV_ID, cell_type_col=settings.CELL_TYPE):
     """Generate the cluster info on all_data using k-means clustering on neighbor_mat.
 
     cluster_num has to be picked based on visualizations from compute_cluster_metrics.
@@ -317,14 +321,10 @@ def generate_cluster_matrix_results(all_data, neighbor_mat, cluster_num, exclude
         cluster_num (int):
             the optimal k to pass into k-means clustering to generate the final clusters
             and corresponding results
-        excluded_colnames (list):
-            all column names that are not markers. If argument is none, default is
-            ["cell_size", "Background", "HH3",
-            "summed_channel", "label", "area",
-            "eccentricity", "major_axis_length",
-            "minor_axis_length", "perimeter", "fov"]
+        excluded_channels (list):
+            all channel names to be excluded from analysis
         included_fovs (list):
-            patient labels to include in analysis. If argument is None, default is all labels used.
+            patient labels to include in analysis. If argument is None, default is all labels used
         cluster_label_col (str):
             the name of the cluster label col we will create
         fov_col (str):
@@ -333,8 +333,9 @@ def generate_cluster_matrix_results(all_data, neighbor_mat, cluster_num, exclude
             the name of the column in all_data determining the cell type
 
     Returns:
-        tuple (pandas.DataFrame, pandas.DataFrame):
+        tuple (pandas.DataFrame, pandas.DataFrame, pandas.DataFrame):
 
+        - the expression matrix with the corresponding cluster labels attached
         - an a x b count matrix (a = # of clusters, b = # of cell types) with
           cluster ids indexed row-wise and cell types indexed column-wise,
           indicates number of cell types that are within each cluster
@@ -347,19 +348,13 @@ def generate_cluster_matrix_results(all_data, neighbor_mat, cluster_num, exclude
     if included_fovs is None:
         included_fovs = neighbor_mat[fov_col].unique()
 
-    if excluded_colnames is None:
-        excluded_colnames = ["cell_size", "Background", "HH3",
-                             "summed_channel", "label", "area",
-                             "eccentricity", "major_axis_length", "minor_axis_length",
-                             "perimeter", "fov"]
+    # check if included fovs found in fov_col
+    misc_utils.verify_in_list(fov_names=included_fovs,
+                              unique_fovs=all_data[fov_col].unique())
 
-    # make sure the specified excluded_colnames exist in all_data
-    if not np.isin(excluded_colnames, all_data.columns).all():
-        raise ValueError("Column names were not found in Expression Matrix")
-
-    # make sure the specified fovs exist in included_fovs
-    if not np.isin(included_fovs, neighbor_mat[fov_col]).all():
-        raise ValueError("Not all specified fovs exist in the provided neighborhood matrix")
+    # check if all excluded column names found in all_data
+    misc_utils.verify_in_list(columns_to_exclude=excluded_channels,
+                              column_names=all_data.columns)
 
     # make sure number of clusters specified is valid
     if cluster_num < 2:
@@ -384,13 +379,27 @@ def generate_cluster_matrix_results(all_data, neighbor_mat, cluster_num, exclude
     num_cell_type_per_cluster = group_by_cell_type.pivot(
         index=cluster_label_col, columns=cell_type_col, values="count").fillna(0).astype(int)
 
+    # annotate index with "Cluster" to make visualization clear that these are cluster labels
+    num_cell_type_per_cluster.index = ["Cluster" + str(c)
+                                       for c in num_cell_type_per_cluster.index]
+
     # Subsets the expression matrix to only have channel columns
-    all_data_markers_clusters = all_data_clusters.drop(excluded_colnames, axis=1)
+    channel_start = np.where(all_data_clusters.columns == settings.PRE_CHANNEL_COL)[0][0] + 1
+    channel_end = np.where(all_data_clusters.columns == settings.POST_CHANNEL_COL)[0][0]
+    cluster_label_colnum = np.where(all_data_clusters.columns == cluster_label_col)[0][0]
+
+    all_data_markers_clusters = \
+        all_data_clusters.iloc[:, list(range(channel_start, channel_end)) + [cluster_label_colnum]]
+    all_data_markers_clusters = all_data_markers_clusters.drop(excluded_channels, axis=1)
 
     # create a mean pivot table with cluster_label_col as row and channels as column
     mean_marker_exp_per_cluster = all_data_markers_clusters.groupby([cluster_label_col]).mean()
 
-    return num_cell_type_per_cluster, mean_marker_exp_per_cluster
+    # annotate index with "Cluster" to make visualization clear that these are cluster labels
+    mean_marker_exp_per_cluster.index = ["Cluster" + str(c)
+                                         for c in mean_marker_exp_per_cluster.index]
+
+    return all_data_clusters, num_cell_type_per_cluster, mean_marker_exp_per_cluster
 
 
 def compute_cluster_metrics(neighbor_mat, max_k=10, included_fovs=None,
@@ -423,9 +432,9 @@ def compute_cluster_metrics(neighbor_mat, max_k=10, included_fovs=None,
     if max_k < 2:
         raise ValueError("Invalid k provided for clustering")
 
-    # make sure the fovs specified all exist inside the fov_col
-    if not np.isin(included_fovs, neighbor_mat[fov_col]).all():
-        raise ValueError("Not all specified fovs exist in the provided neighborhood matrix")
+    # check if included fovs found in fov_col
+    misc_utils.verify_in_list(fov_names=included_fovs,
+                              unique_fovs=neighbor_mat[fov_col].unique())
 
     # subset neighbor_mat accordingly, and drop the columns we don't need
     neighbor_mat_data = neighbor_mat[neighbor_mat[fov_col].isin(included_fovs)]
