@@ -52,7 +52,6 @@ def calculate_channel_percentiles(tiff_dir, fovs, channels, img_sub_folder, perc
     for channel in channels:
         percentile_list = []
         for fov in fovs:
-
             # load image data and remove 0 valued pixels
             img = load_utils.load_imgs_from_tree(data_dir=tiff_dir, img_sub_folder=img_sub_folder,
                                                  channels=[channel], fovs=[fov]).values[0, :, :, 0]
@@ -857,6 +856,8 @@ def preprocess_fov(base_dir, tiff_dir, data_dir, subset_dir, seg_dir, seg_suffix
 
 def create_pixel_matrix(fovs, channels, base_dir, tiff_dir, seg_dir,
                         img_sub_folder="TIFs", seg_suffix='_feature_0.tif',
+                        pixel_cluster_prefix='pixel_cluster_prefix',
+                        pixel_output_dir='pixel_output_dir',
                         data_dir='pixel_mat_data',
                         subset_dir='pixel_mat_subsetted',
                         norm_vals_name='post_rowsum_chan_norm.feather', is_mibitiff=False,
@@ -884,10 +885,18 @@ def create_pixel_matrix(fovs, channels, base_dir, tiff_dir, seg_dir,
         seg_suffix (str):
             The suffix that the segmentation images use.
             Ignored if `seg_dir` is `None`.
+        pixel_cluster_prefix (str):
+            The name of the prefix to append before each pixel clustering directory/file,
+            needed to name the channel and pixel norm files
+        pixel_output_dir (str):
+            The name of the data directory containing the pixel data to use for the
+            clustering pipeline. `data_dir` and `subset_dir` should be placed here.
         data_dir (str):
-            Name of the directory which contains the full preprocessed pixel data
+            Name of the directory which contains the full preprocessed pixel data.
+            Should be placed in `pixel_output_dir`.
         subset_dir (str):
-            The name of the directory containing the subsetted pixel data
+            The name of the directory containing the subsetted pixel data.
+            Should be placed in `pixel_output_dir`.
         norm_vals_name (str):
             The name of the file to store the 99.9% normalization values
         is_mibitiff (bool):
@@ -918,6 +927,10 @@ def create_pixel_matrix(fovs, channels, base_dir, tiff_dir, seg_dir,
     if not os.path.exists(tiff_dir):
         raise FileNotFoundError("tiff_dir %s does not exist" % tiff_dir)
 
+    # if the pixel output dir doesn't exist
+    if not os.path.exists(os.path.join(base_dir, pixel_output_dir)):
+        raise FileNotFoundError("pixel_output_dir %s does not exist" % pixel_output_dir)
+
     # create data_dir if it doesn't already exist
     if not os.path.exists(os.path.join(base_dir, data_dir)):
         os.mkdir(os.path.join(base_dir, data_dir))
@@ -934,7 +947,9 @@ def create_pixel_matrix(fovs, channels, base_dir, tiff_dir, seg_dir,
     quant_dat = pd.DataFrame()
 
     # create path for channel normalization values
-    channel_norm_path = os.path.join(base_dir, 'channel_norm.feather')
+    channel_norm_path = os.path.join(
+        base_dir, pixel_output_dir, '%s_channel_norm.feather' % pixel_cluster_prefix
+    )
 
     if not os.path.exists(channel_norm_path):
         # compute channel percentiles
@@ -950,7 +965,10 @@ def create_pixel_matrix(fovs, channels, base_dir, tiff_dir, seg_dir,
         channel_norm_df = feather.read_dataframe(channel_norm_path)
 
     # create path for pixel normalization values
-    pixel_norm_path = os.path.join(base_dir, 'pixel_norm.feather')
+    pixel_norm_path = os.path.join(
+        base_dir, pixel_output_dir, '%s_pixel_norm.feather' % pixel_cluster_prefix
+    )
+
     if not os.path.exists(pixel_norm_path):
         # compute pixel percentiles
         pixel_norm_val = calculate_pixel_intensity_percentile(
