@@ -1,4 +1,5 @@
 import copy
+import warnings
 
 import numpy as np
 import pandas as pd
@@ -41,6 +42,12 @@ def get_single_compartment_props(segmentation_labels, regionprops_base,
         props_options=list(REGIONPROPS_FUNCTION.keys())
     )
 
+    # if image is just background, return empty df
+    if len(np.unique(segmentation_labels)) < 2:
+        output_list = regionprops_base + regionprops_single_comp
+        blank_df = pd.DataFrame(columns=output_list)
+        return blank_df
+
     # get the base features
     cell_props = pd.DataFrame(regionprops_table(segmentation_labels,
                                                 properties=regionprops_base))
@@ -107,13 +114,19 @@ def assign_single_compartment_features(marker_counts, compartment, cell_props, c
     cell_counts = EXTRACTION_FUNCTION[extraction](cell_coords, input_images, **kwargs)
 
     # get morphology metrics
-    current_cell_props = cell_props.loc[cell_props['label'] == label_id, regionprops_names]
+    # Filter regionprops_names to only those in cell_props.columns
+    filtered_regionprops_names = [rp_name for rp_name in regionprops_names if rp_name in
+                                  cell_props.columns]
+    current_cell_props = cell_props.loc[cell_props['label'] == label_id,
+                                        filtered_regionprops_names]
 
     # combine marker counts and morphology metrics together
     cell_features = np.concatenate((cell_counts, current_cell_props), axis=None)
 
     # add counts of each marker to appropriate column
-    marker_counts.loc[compartment, cell_id, marker_counts.features[1]:] = cell_features
+    # Only include the marker_count features up to the last filtered feature.
+    marker_counts.loc[compartment, cell_id,
+                      marker_counts.features[1]:filtered_regionprops_names[-1]] = cell_features
 
     # add cell size to first column
     marker_counts.loc[compartment, cell_id, marker_counts.features[0]] = cell_coords.shape[0]
@@ -144,6 +157,19 @@ def assign_multi_compartment_features(marker_counts, regionprops_multi_comp, **k
     )
 
     for rn in regionprops_multi_comp:
+        # if rn is not a feature, then we add a new dimension to hold this regionprop info
+        if rn not in marker_counts.features.values:
+            rn_fill = np.zeros((marker_counts.shape[0], marker_counts.shape[1], 1))
+            rn_arr = xr.DataArray(
+                rn_fill,
+                coords=[marker_counts.compartments.values, marker_counts.cell_id.values, [rn]],
+                dims=['compartments', 'cell_id', 'features']
+            )
+
+            # append new dimension to marker_counts
+            marker_counts = xr.concat([marker_counts, rn_arr], dim='features')
+
+        # compute the multi-compatment regionprop info
         marker_counts = REGIONPROPS_FUNCTION[rn](marker_counts, **kwargs)
 
     return marker_counts
@@ -216,9 +242,6 @@ def compute_marker_counts(input_images, segmentation_labels, nuclear_counts=Fals
     # add the single compartment features to regionprops_names
     regionprops_names.extend(regionprops_single_comp)
 
-    # add the multi compartment features to regionprops_names
-    regionprops_names.extend(regionprops_multi_comp)
-
     # get all the cell ids
     unique_cell_ids = np.unique(segmentation_labels[..., 0].values)
     unique_cell_ids = unique_cell_ids[np.nonzero(unique_cell_ids)]
@@ -245,6 +268,10 @@ def compute_marker_counts(input_images, segmentation_labels, nuclear_counts=Fals
                                               regionprops_base, regionprops_single_comp,
                                               **reg_props)
 
+    if len(unique_cell_ids) == 0:
+        fov_name = str(segmentation_labels.fovs.values)
+        warnings.warn("No cells found in the following image: {}".format(fov_name))
+
     if nuclear_counts:
         nuc_labels = segmentation_labels.loc[:, :, 'nuclear'].values
 
@@ -258,6 +285,9 @@ def compute_marker_counts(input_images, segmentation_labels, nuclear_counts=Fals
         nuc_props = get_single_compartment_props(nuc_labels,
                                                  regionprops_base, regionprops_single_comp,
                                                  **reg_props)
+        if len(nuc_props) == 0:
+            fov_name = str(segmentation_labels.fovs.values)
+            warnings.warn("No nuclei found in the following image: {}".format(fov_name))
 
     # get the signal kwargs
     sig_kwargs = kwargs.get('signal_kwargs', {})
@@ -293,6 +323,10 @@ def compute_marker_counts(input_images, segmentation_labels, nuclear_counts=Fals
                     marker_counts, regionprops_multi_comp
                 )
 
+                # if regionprops names does not contain multi_comp props then add them
+                if not set(regionprops_multi_comp).issubset(regionprops_names):
+                    regionprops_names.extend(regionprops_multi_comp)
+
     return marker_counts
 
 
@@ -399,19 +433,20 @@ def create_marker_count_matrices(segmentation_labels, image_data, nuclear_counts
     return normalized_data, arcsinh_data
 
 
-def generate_cell_table(segmentation_labels, tiff_dir, img_sub_folder,
+def generate_cell_table(segmentation_dir, tiff_dir, img_sub_folder="TIFs",
                         is_mibitiff=False, fovs=None, batch_size=5, dtype="int16",
-                        extraction='total_intensity', **kwargs):
+                        extraction='total_intensity', nuclear_counts=False, **kwargs):
     """This function takes the segmented data and computes the expression matrices batch-wise
     while also validating inputs
 
     Args:
-        segmentation_labels (xarray.DataArray):
-            an xarray with the segmented data
+        segmentation_dir (str):
+            the path to the directory containing the segmentation labels generated by Mesmer
         tiff_dir (str):
             the name of the directory which contains the single_channel_inputs
         img_sub_folder (str):
             the name of the folder where the TIF images are located
+            ignored if is_mibitiff is True
         fovs (list):
             a list of fovs we wish to analyze, if None will default to all fovs
         is_mibitiff (bool):
@@ -422,12 +457,15 @@ def generate_cell_table(segmentation_labels, tiff_dir, img_sub_folder,
         dtype (str/type):
             data type of base images
         extraction (str):
-            extraction function used to compute marker counts.
+            extraction function used to compute marker counts
+        nuclear_counts (bool):
+            boolean flag to determine whether nuclear counts are returned, note that if
+            set to True, the compartments coordinate in segmentation_labels must contain 'nuclear'
         **kwargs:
             arbitrary keyword arguments for signal and regionprops extraction
 
     Returns:
-        tuple (pandas.DataFrame, pandas.DataFrame):å
+        tuple (pandas.DataFrame, pandas.DataFrame):
         - size normalized data
         - arcsinh transformed data
     """
@@ -447,10 +485,6 @@ def generate_cell_table(segmentation_labels, tiff_dir, img_sub_folder,
         extraction_options=list(EXTRACTION_FUNCTION.keys())
     )
 
-    # check segmentation_labels for given fovs (img loaders will fail otherwise)
-    misc_utils.verify_in_list(fovs=fovs,
-                              segmentation_labels_fovs=segmentation_labels['fovs'].values)
-
     # get full filenames from given fovs
     filenames = io_utils.list_files(tiff_dir, substrs=fovs, exact_match=True)
 
@@ -481,14 +515,40 @@ def generate_cell_table(segmentation_labels, tiff_dir, img_sub_folder,
                                                         fovs=batch_names,
                                                         dtype=dtype)
 
-        # as well as the labels corresponding to each of them
-        current_labels = segmentation_labels.loc[batch_names, :, :, :]
+        # define the files for whole cell and nuclear
+        whole_cell_files = [fov + '_feature_0.tif' for fov in batch_names]
+        nuclear_files = [fov + '_feature_1.tif' for fov in batch_names]
+
+        # load the segmentation labels in
+        current_labels_cell = load_utils.load_imgs_from_dir(data_dir=segmentation_dir,
+                                                            files=whole_cell_files,
+                                                            xr_dim_name='compartments',
+                                                            xr_channel_names=['whole_cell'],
+                                                            trim_suffix='_feature_0',
+                                                            force_ints=True)
+
+        current_labels_nuc = load_utils.load_imgs_from_dir(data_dir=segmentation_dir,
+                                                           files=nuclear_files,
+                                                           xr_dim_name='compartments',
+                                                           xr_channel_names=['nuclear'],
+                                                           trim_suffix='_feature_1',
+                                                           force_ints=True)
+
+        current_labels = xr.DataArray(np.concatenate((current_labels_cell.values,
+                                                      current_labels_nuc.values),
+                                                     axis=-1),
+                                      coords=[current_labels_cell.fovs,
+                                              current_labels_cell.rows,
+                                              current_labels_cell.cols,
+                                              ['whole_cell', 'nuclear']],
+                                      dims=current_labels_cell.dims)
 
         # segment the imaging data
         cell_table_size_normalized, cell_table_arcsinh_transformed = create_marker_count_matrices(
             segmentation_labels=current_labels,
             image_data=image_data,
             extraction=extraction,
+            nuclear_counts=nuclear_counts,
             **kwargs
         )
 
