@@ -51,23 +51,41 @@ def test_positive_pixels_extraction():
     assert np.all(channel_counts_2 == [0, 236])
 
     # test with new threshold == 10
-    test_threshold = 10
+    kwargs = {'threshold': 10}
 
     channel_counts_1 = signal_extraction.positive_pixels_extraction(
         cell_coords=coords_1,
         image_data=xr.DataArray(sample_channel_data),
-        threshold=test_threshold
+        **kwargs
     )
 
     channel_counts_2 = signal_extraction.positive_pixels_extraction(
         cell_coords=coords_2,
         image_data=xr.DataArray(sample_channel_data),
-        threshold=test_threshold
+        **kwargs
     )
 
     assert np.all(channel_counts_1 == [0, 0])
     assert np.all(channel_counts_2 == [0, 236])
 
+    # test for multichannel thresholds
+    kwargs = {'threshold': np.array([0, 10])}
+
+    channel_counts_1 = signal_extraction.positive_pixels_extraction(
+        cell_coords=coords_1,
+        image_data=xr.DataArray(sample_channel_data),
+        **kwargs
+    )
+
+    channel_counts_2 = signal_extraction.positive_pixels_extraction(
+        cell_coords=coords_2,
+        image_data=xr.DataArray(sample_channel_data),
+        **kwargs
+    )
+
+    assert np.all(channel_counts_1 == [25, 0])
+    assert np.all(channel_counts_2 == [0, 236])
+
 
 def test_center_weighting_extraction():
     # sample params
@@ -99,8 +117,8 @@ def test_center_weighting_extraction():
 
     # extract the centroids and coords
     region_info = regionprops(sample_segmentation_mask.astype(np.int16))
-    centroid_1 = region_info[0].centroid
-    centroid_2 = region_info[1].centroid
+    kwarg_1 = {'centroid': region_info[0].centroid}
+    kwarg_2 = {'centroid': region_info[1].centroid}
 
     coords_1 = region_info[0].coords
     coords_2 = region_info[1].coords
@@ -108,21 +126,21 @@ def test_center_weighting_extraction():
     channel_counts_1_center_weight = signal_extraction.center_weighting_extraction(
         cell_coords=coords_1,
         image_data=xr.DataArray(sample_channel_data),
-        centroid=centroid_1
+        **kwarg_1
     )
 
     channel_counts_2_center_weight = signal_extraction.center_weighting_extraction(
         cell_coords=coords_2,
         image_data=xr.DataArray(sample_channel_data),
-        centroid=centroid_2
+        **kwarg_2
     )
 
-    channel_counts_1_base_weight = signal_extraction.default_extraction(
+    channel_counts_1_base_weight = signal_extraction.total_intensity_extraction(
         cell_coords=coords_1,
         image_data=xr.DataArray(sample_channel_data)
     )
 
-    channel_counts_2_base_weight = signal_extraction.default_extraction(
+    channel_counts_2_base_weight = signal_extraction.total_intensity_extraction(
         cell_coords=coords_2,
         image_data=xr.DataArray(sample_channel_data)
     )
@@ -135,7 +153,7 @@ def test_center_weighting_extraction():
     assert channel_counts_1_center_weight[1] < channel_counts_1_base_weight[1]
 
 
-def test_default_extraction():
+def test_total_intensity_extraction():
     # sample params
     size_img = (1024, 1024)
     cell_radius = 10
@@ -163,12 +181,12 @@ def test_default_extraction():
     coords_1 = np.argwhere(sample_segmentation_mask == 1)
     coords_2 = np.argwhere(sample_segmentation_mask == 2)
 
-    channel_counts_1 = signal_extraction.default_extraction(
+    channel_counts_1 = signal_extraction.total_intensity_extraction(
         cell_coords=coords_1,
         image_data=xr.DataArray(sample_channel_data)
     )
 
-    channel_counts_2 = signal_extraction.default_extraction(
+    channel_counts_2 = signal_extraction.total_intensity_extraction(
         cell_coords=coords_2,
         image_data=xr.DataArray(sample_channel_data)
     )
