@@ -1,3 +1,4 @@
+import os
 import numpy as np
 import xarray as xr
 import pandas as pd
@@ -7,16 +8,18 @@ import scipy
 from statsmodels.stats.multitest import multipletests
 from sklearn.cluster import KMeans
 from scipy.spatial.distance import cdist
-import os
+
+import ark.settings as settings
+from ark.utils import io_utils, misc_utils
 
 
-def calc_dist_matrix(label_maps, path=None):
+def calc_dist_matrix(label_maps, save_path=None):
     """Generate matrix of distances between center of pairs of cells
 
     Args:
         label_maps (xarray.DataArray):
             array of segmentation masks indexed by (fov, cell_id, cell_id, segmentation_label)
-        path (str):
+        save_path (str):
             path to save file. If None, then will directly return
     Returns:
         dict:
@@ -27,9 +30,8 @@ def calc_dist_matrix(label_maps, path=None):
 
     # Check that file path exists, if given
 
-    if path is not None:
-        if not os.path.exists(path):
-            raise FileNotFoundError("File path not valid")
+    if save_path is not None:
+        io_utils.validate_paths(save_path, data_prefix=False)
 
     dist_mats_list = []
 
@@ -43,7 +45,7 @@ def calc_dist_matrix(label_maps, path=None):
         centroid_labels = [prop.label for prop in props]
 
         # generate the distance matrix, then assign centroid_labels as coords
-        dist_matrix = cdist(centroids, centroids)
+        dist_matrix = cdist(centroids, centroids).astype(np.float32)
         dist_mat_xarr = xr.DataArray(dist_matrix, coords=[centroid_labels, centroid_labels])
 
         # append final result to dist_mats_list
@@ -52,12 +54,12 @@ def calc_dist_matrix(label_maps, path=None):
     # Create dictionary to store distance matrices per fov
     dist_matrices = dict(zip(fovs, dist_mats_list))
 
-    # If path is None, function will directly return the dictionary
-    # else it will save it as a file with location specified by path
-    if path is None:
+    # If save_path is None, function will directly return the dictionary
+    # else it will save it as a file with location specified by save_path
+    if save_path is None:
         return dist_matrices
     else:
-        np.savez(path + "dist_matrices.npz", **dist_matrices)
+        np.savez(os.path.join(save_path, "dist_matrices.npz"), **dist_matrices)
 
 
 def get_pos_cell_labels_channel(thresh, current_fov_channel_data, cell_labels, current_marker):
@@ -118,7 +120,7 @@ def get_pos_cell_labels_cluster(pheno, current_fov_neighborhood_data,
 def compute_close_cell_num(dist_mat, dist_lim, analysis_type,
                            current_fov_data=None, current_fov_channel_data=None,
                            cluster_ids=None, cell_types_analyze=None, thresh_vec=None,
-                           cell_label_col="cellLabelInImage", cell_type_col="FlowSOM_ID"):
+                           cell_label_col=settings.CELL_LABEL, cell_type_col=settings.CLUSTER_ID):
     """Finds positive cell labels and creates matrix with counts for cells positive for
     corresponding markers. Computes close_num matrix for both Cell Label and Threshold spatial
     analyses.
@@ -135,7 +137,7 @@ def compute_close_cell_num(dist_mat, dist_lim, analysis_type,
         dist_lim (int):
             threshold for spatial enrichment distance proximity
         analysis_type (str):
-            type of analysis, either cluster or channel
+            type of analysis, must be either cluster or channel
         current_fov_data (pandas.DataFrame):
             data for specific patient in expression matrix
         current_fov_channel_data (pandas.DataFrame):
@@ -158,8 +160,8 @@ def compute_close_cell_num(dist_mat, dist_lim, analysis_type,
     """
 
     # assert our analysis type is valid
-    if not np.isin(analysis_type, ("cluster", "channel")).all():
-        raise ValueError("Incorrect analysis type")
+    good_analyses = ["cluster", "channel"]
+    misc_utils.verify_in_list(analysis_type=analysis_type, good_analyses=good_analyses)
 
     # Initialize variables
 
@@ -177,13 +179,13 @@ def compute_close_cell_num(dist_mat, dist_lim, analysis_type,
         num = len(cluster_ids)
 
     # Create close_num, marker1_num, and marker2_num
-    close_num = np.zeros((num, num), dtype='int')
+    close_num = np.zeros((num, num), dtype=np.uint16)
 
     mark1_num = []
     mark1poslabels = []
 
     dist_mat_bin = xr.DataArray(
-        (dist_mat.values < dist_lim).astype(np.int8),
+        (dist_mat.values < dist_lim).astype(np.uint8),
         coords=dist_mat.coords
     )
 
@@ -216,7 +218,7 @@ def compute_close_cell_num(dist_mat, dist_lim, analysis_type,
                 mark1poslabels[j].values,
                 mark1poslabels[k].values
             ].values
-            count_close_num_hits = np.sum(dist_mat_bin_subset)
+            count_close_num_hits = np.sum(dist_mat_bin_subset, dtype=np.uint16)
 
             close_num[j, k] = count_close_num_hits
             # symmetry :)
@@ -246,20 +248,16 @@ def compute_close_cell_num_random(marker_nums, dist_mat, dist_lim, bootstrap_num
 
     # Create close_num_rand
     close_num_rand = np.zeros((
-        len(marker_nums), len(marker_nums), bootstrap_num), dtype='int')
+        len(marker_nums), len(marker_nums), bootstrap_num), dtype=np.uint16)
 
-    dist_mat_bin = xr.DataArray(
-        (dist_mat.values < dist_lim).astype(np.int8),
-        coords=dist_mat.coords
-    )
+    dist_mat_bin_flattened = (dist_mat.values < dist_lim).astype(np.uint8).flatten()
 
     for j, m1n in enumerate(marker_nums):
         for k, m2n in enumerate(marker_nums[j:], j):
             samples_dim = (m1n * m2n, bootstrap_num)
-            dist_mat_bin_flattened = dist_mat_bin.values.flatten()
             count_close_num_rand_hits = np.sum(
-                np.random.choice(dist_mat_bin_flattened, samples_dim, True),
-                axis=0
+                np.random.choice(dist_mat_bin_flattened, samples_dim, True), axis=0,
+                dtype=np.uint16
             )
 
             close_num_rand[j, k, :] = count_close_num_rand_hits
@@ -335,7 +333,7 @@ def calculate_enrichment_stats(close_num, close_num_rand):
 
 
 def compute_neighbor_counts(current_fov_neighborhood_data, dist_matrix, distlim,
-                            self_neighbor=True, cell_label_col="cellLabelInImage"):
+                            self_neighbor=True, cell_label_col=settings.CELL_LABEL):
     """Calculates the number of neighbor phenotypes for each cell. The cell counts itself as a
     neighbor.
 
