@@ -2,16 +2,22 @@ import os
 from copy import deepcopy
 from random import choices
 from string import ascii_lowercase
+
 import numpy as np
 import pandas as pd
-import xarray as xr
 import skimage.io as io
+import xarray as xr
 
 import ark.settings as settings
 from ark.utils import synthetic_spatial_datagen
 from ark.utils.tiff_utils import write_mibitiff
 
 
+def _make_blank_file(folder, name):
+    with open(os.path.join(folder, name), 'w'):
+        pass
+
+
 def gen_fov_chan_names(num_fovs, num_chans, return_imgs=False, use_delimiter=False):
     """Generate fov and channel names
 
@@ -175,7 +181,8 @@ def _write_tifs(base_dir, fov_names, img_names, shape, sub_dir, fills, dtype):
         fov_path = os.path.join(base_dir, fov, sub_dir)
         os.makedirs(fov_path)
         for j, name in enumerate(img_names):
-            io.imsave(os.path.join(fov_path, f'{name}.tiff'), tif_data[i, :, :, j])
+            io.imsave(os.path.join(fov_path, f'{name}.tiff'), tif_data[i, :, :, j],
+                      check_contrast=False)
             filelocs[fov].append(os.path.join(fov_path, name))
 
     return filelocs, tif_data
@@ -220,7 +227,8 @@ def _write_multitiff(base_dir, fov_names, channel_names, shape, sub_dir, fills,
         v = tif_data[i, :, :, :]
         if channels_first:
             v = np.moveaxis(v, -1, 0)
-        io.imsave(tiffpath, v, plugin='tifffile')
+        io.imsave(tiffpath, v, plugin='tifffile',
+                  check_contrast=False)
         filelocs[fov] = tiffpath
 
     return filelocs, tif_data
@@ -303,7 +311,8 @@ def _write_reverse_multitiff(base_dir, fov_names, channel_names, shape, sub_dir,
 
     for i, fov in enumerate(fov_names):
         tiffpath = os.path.join(base_dir, f'{fov}.tiff')
-        io.imsave(tiffpath, tif_data[:, :, :, i], plugin='tifffile')
+        io.imsave(tiffpath, tif_data[:, :, :, i], plugin='tifffile',
+                  check_contrast=False)
         filelocs[fov] = tiffpath
 
     tif_data = np.swapaxes(tif_data, 0, -1)
@@ -342,7 +351,8 @@ def _write_labels(base_dir, fov_names, comp_names, shape, sub_dir, fills, dtype)
 
     for i, fov in enumerate(fov_names):
         tiffpath = os.path.join(base_dir, f'{fov}.tiff')
-        io.imsave(tiffpath, label_data[i, :, :, 0], plugin='tifffile')
+        io.imsave(tiffpath, label_data[i, :, :, 0], plugin='tifffile',
+                  check_contrast=False)
         filelocs[fov] = tiffpath
 
     return filelocs, label_data
@@ -533,29 +543,61 @@ def make_labels_xarray(label_data, fov_ids=None, compartment_names=None, row_siz
 TEST_MARKERS = list('ABCDEFG')
 
 
-def make_segmented_csv(num_cells, extra_cols=None):
-    """ Generate segmented 'csv' file
+def make_cell_table(num_cells, extra_cols=None):
+    """ Generate a cell table with default column names for testing purposes.
 
     Args:
         num_cells (int):
-            Number of rows (cells) in csv
+            Number of rows (cells) in the cell table
         extra_cols (dict):
             Extra columns to add in the format ``{'Column_Name' : data_1D, ...}``
 
     Returns:
         pandas.DataFrame:
-            segmented csv data
+            A structural example of a cell table containing simulated marker expressions,
+            cluster labels, centroid coordinates, and more.
 
     """
-    cell_data = pd.DataFrame(
-        np.random.random(size=(num_cells, len(TEST_MARKERS))),
-        columns=TEST_MARKERS
-    )
-    cell_data[settings.CELL_TYPE] = choices(ascii_lowercase, k=num_cells)
-    cell_data[settings.PATIENT_ID] = choices(range(1, 10), k=num_cells)
+    # columns from regionprops extraction
+    region_cols = [x for x in settings.REGIONPROPS_BASE if
+                   x not in ['label', 'area', 'centroid']] + settings.REGIONPROPS_SINGLE_COMP
+    region_cols += settings.REGIONPROPS_MULTI_COMP
+    # consistent ordering of column names
+    column_names = [settings.FOV_ID,
+                    settings.PATIENT_ID,
+                    settings.CLUSTER_ID,
+                    settings.KMEANS_CLUSTER,
+                    settings.CELL_LABEL,
+                    settings.CELL_TYPE,
+                    settings.CELL_SIZE] + TEST_MARKERS + region_cols + ['centroid-0', 'centroid-1']
+
+    if extra_cols is not None:
+        column_names += list(extra_cols.values())
+
+    # random filler data
+    cell_data = pd.DataFrame(np.random.random(size=(num_cells, len(column_names))),
+                             columns=column_names)
+    # not-so-random filler data
+    cluster_id = choices(range(1, 21), k=num_cells)
+    centroids = pd.DataFrame(np.array([(x, y) for x in range(1024) for y in range(1024)]))
+    centroid_loc = np.random.choice(range(1024 ** 2), size=num_cells, replace=False)
+    fields = [(settings.FOV_ID, choices(range(1, 5), k=num_cells)),
+              (settings.PATIENT_ID, choices(range(1, 10), k=num_cells)),
+              (settings.CLUSTER_ID, cluster_id),
+              (settings.KMEANS_CLUSTER, [ascii_lowercase[i] for i in cluster_id]),
+              (settings.CELL_LABEL, list(range(num_cells))),
+              (settings.CELL_TYPE, choices(ascii_lowercase, k=num_cells)),
+              (settings.CELL_SIZE, np.random.uniform(100, 300, size=num_cells)),
+              (settings.CENTROID_0, np.array(centroids.iloc[centroid_loc, 0])),
+              (settings.CENTROID_1, np.array(centroids.iloc[centroid_loc, 1]))
+              ]
+
+    for name, col in fields:
+        cell_data[name] = col
 
     return cell_data
 
+
 # TODO: Use these below
 
 
@@ -1000,3 +1042,73 @@ def _make_dist_exp_mats_spatial_utils_test():
     dist_mat = _make_dist_mat_sa_utils()
 
     return all_data, dist_mat
+
+
+def generate_sample_fov_tiling_entry(coord, name):
+    """Generates a sample fov entry to put in a sample fovs list for tiling
+
+    Args:
+        coord (tuple):
+            Defines the starting x and y point for the fov
+        name (str):
+            Defines the name of the fov
+
+    Returns:
+        dict:
+            An entry to be placed in the fovs list with provided coordinate and name
+    """
+
+    sample_fov_tiling_entry = {
+        "scanCount": 1,
+        "centerPointMicrons": {
+            "x": coord[0],
+            "y": coord[1]
+        },
+        "timingChoice": 7,
+        "frameSizePixels": {
+            "width": 2048,
+            "height": 2048
+        },
+        "imagingPreset": {
+            "preset": "Normal",
+            "aperture": "2",
+            "displayName": "Fine",
+            "defaults": {
+              "timingChoice": 7
+            }
+        },
+        "sectionId": 8201,
+        "slideId": 5931,
+        "name": name,
+        "timingDescription": "1 ms"
+    }
+
+    return sample_fov_tiling_entry
+
+
+def generate_sample_fovs_list(fov_coords, fov_names):
+    """Generate a sample dictionary of fovs for tiling
+
+    Args:
+        fov_coords (list):
+            A list of tuples listing the starting x and y coordinates of each fov
+        fov_names (list):
+            A list of strings identifying the name of each fov
+
+    Returns:
+        dict:
+            A dummy fovs list with starting x and y set to the provided coordinates and name
+    """
+
+    sample_fovs_list = {
+        "exportDateTime": "2021-03-12T19:02:37.920Z",
+        "fovFormatVersion": "1.5",
+        "fovs": []
+    }
+
+    for coord, name in zip(fov_coords, fov_names):
+        sample_fovs_list["fovs"].append(
+            generate_sample_fov_tiling_entry(coord, name)
+        )
+
+    return sample_fovs_list
